@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  * 
@@ -41,7 +42,7 @@
 #include <unotools/accessiblerelationsethelper.hxx>
 #include <tools/diagnose_ex.h>
 #include <vcl/svapp.hxx>
-#include <vos/mutex.hxx>
+#include <osl/mutex.hxx>
 
 //......................................................................................................................
 namespace accessibility
@@ -257,7 +258,7 @@ namespace accessibility
     {
     public:
         ItemMethodGuard( AccessibleToolPanelDeckTabBarItem_Impl& i_rImpl )
-            :m_aGuard( Application::GetSolarMutex() )
+            :m_aGuard()
         {
             i_rImpl.checkDisposed();
         }
@@ -265,13 +266,8 @@ namespace accessibility
         {
         }
 
-        void clear()
-        {
-            m_aGuard.clear();
-        }
-
     private:
-        ::vos::OClearableGuard  m_aGuard;
+        SolarMutexGuard  m_aGuard;
     };
 
     //==================================================================================================================
@@ -453,3 +449,5 @@ namespace accessibility
 //......................................................................................................................
 } // namespace accessibility
 //......................................................................................................................
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
