@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -30,14 +31,10 @@
 #include <tools/time.hxx>
 #include <vcl/splitwin.hxx>
 #include <vcl/wrkwin.hxx>
-#ifndef _BASIC_TTRESHLP_HXX
 #include <basic/ttstrhlp.hxx>
-#endif
 #include "statemnt.hxx"
 
-#ifndef _RETSRTM_HXX
 #include "retstrm.hxx"
-#endif
 #include "rcontrol.hxx"
 
 #if OSL_DEBUG_LEVEL > 1
@@ -1224,3 +1221,4 @@ void ImplCommand( Window* pWin, CommandEvent &aCmdEvnt )
     CALL_EVENT_WITH_NOTIFY( EVENT_COMMAND, aCmdEvnt, pWin, Command )
 };
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
