@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -52,9 +53,7 @@
 #include <sbxitem.hxx>
 #include <sfx2/minfitem.hxx>
 
-#ifndef _COM_SUN_STAR_SCRIPT_XLIBRYARYCONTAINER2_HPP_
 #include <com/sun/star/script/XLibraryContainer2.hpp>
-#endif
 #include <com/sun/star/document/MacroExecMode.hpp>
 
 using namespace ::com::sun::star;
@@ -921,3 +920,4 @@ String MacroChooser::GetInfo( SbxVariable* pVar )
     return aComment;
 }
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
