@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -42,6 +43,8 @@
 #include <sfx2/minfitem.hxx>
 #include <svl/stritem.hxx>
 
+#include <sal/macros.h>
+
 #include "cuires.hrc"
 #include "acccfg.hrc"
 
@@ -58,9 +61,7 @@
 #include <com/sun/star/ui/XModuleUIConfigurationManagerSupplier.hpp>
 #include <com/sun/star/frame/XModuleManager.hpp>
 
-#ifndef _COM_SUN_STAR_UI_XUICONFIGURATIONMANAGERSUPLLIER_HPP_
 #include <com/sun/star/ui/XUIConfigurationManagerSupplier.hpp>
-#endif
 #include <com/sun/star/ui/XUIConfigurationManager.hpp>
 #include <com/sun/star/awt/KeyModifier.hpp>
 #include <com/sun/star/embed/XTransactedObject.hpp>
@@ -218,6 +219,9 @@ static USHORT __FAR_DATA KEYCODE_ARRAY[] =
     KEY_X         | KEY_MOD1 ,
     KEY_Y         | KEY_MOD1 ,
     KEY_Z         | KEY_MOD1 ,
+    KEY_SEMICOLON    | KEY_MOD1 ,
+    KEY_BRACKETLEFT  | KEY_MOD1 ,
+    KEY_BRACKETRIGHT | KEY_MOD1,
 
     KEY_F1        | KEY_MOD1 ,
     KEY_F2        | KEY_MOD1 ,
@@ -287,6 +291,9 @@ static USHORT __FAR_DATA KEYCODE_ARRAY[] =
     KEY_X         | KEY_SHIFT | KEY_MOD1,
     KEY_Y         | KEY_SHIFT | KEY_MOD1,
     KEY_Z         | KEY_SHIFT | KEY_MOD1,
+    KEY_SEMICOLON    | KEY_SHIFT | KEY_MOD1 ,
+    KEY_BRACKETLEFT  | KEY_SHIFT | KEY_MOD1 ,
+    KEY_BRACKETRIGHT | KEY_SHIFT | KEY_MOD1,
 
     KEY_F1        | KEY_SHIFT | KEY_MOD1,
     KEY_F2        | KEY_SHIFT | KEY_MOD1,
@@ -351,6 +358,9 @@ static USHORT __FAR_DATA KEYCODE_ARRAY[] =
     KEY_X         | KEY_MOD2 ,
     KEY_Y         | KEY_MOD2 ,
     KEY_Z         | KEY_MOD2 ,
+    KEY_SEMICOLON    | KEY_MOD2 ,
+    KEY_BRACKETLEFT  | KEY_MOD2 ,
+    KEY_BRACKETRIGHT | KEY_MOD2,
 
     KEY_F1        | KEY_MOD2 ,
     KEY_F2        | KEY_MOD2 ,
@@ -415,6 +425,9 @@ static USHORT __FAR_DATA KEYCODE_ARRAY[] =
     KEY_X         | KEY_SHIFT | KEY_MOD2,
     KEY_Y         | KEY_SHIFT | KEY_MOD2,
     KEY_Z         | KEY_SHIFT | KEY_MOD2,
+    KEY_SEMICOLON    | KEY_SHIFT | KEY_MOD2 ,
+    KEY_BRACKETLEFT  | KEY_SHIFT | KEY_MOD2 ,
+    KEY_BRACKETRIGHT | KEY_SHIFT | KEY_MOD2,
 
     KEY_F1        | KEY_SHIFT | KEY_MOD2,
     KEY_F2        | KEY_SHIFT | KEY_MOD2,
@@ -543,6 +556,9 @@ static USHORT __FAR_DATA KEYCODE_ARRAY[] =
     KEY_X         | KEY_SHIFT | KEY_MOD1 | KEY_MOD2,
     KEY_Y         | KEY_SHIFT | KEY_MOD1 | KEY_MOD2,
     KEY_Z         | KEY_SHIFT | KEY_MOD1 | KEY_MOD2,
+    KEY_SEMICOLON    | KEY_SHIFT | KEY_MOD1 | KEY_MOD2,
+    KEY_BRACKETLEFT  | KEY_SHIFT | KEY_MOD1 | KEY_MOD2,
+    KEY_BRACKETRIGHT | KEY_SHIFT | KEY_MOD1 | KEY_MOD2,
 
     KEY_F1        | KEY_SHIFT | KEY_MOD1 | KEY_MOD2,
     KEY_F2        | KEY_SHIFT | KEY_MOD1 | KEY_MOD2,
@@ -572,7 +588,7 @@ static USHORT __FAR_DATA KEYCODE_ARRAY[] =
     KEY_DELETE    | KEY_SHIFT | KEY_MOD1 | KEY_MOD2
 };
 
-static USHORT KEYCODE_ARRAY_SIZE = (sizeof(KEYCODE_ARRAY) / sizeof(KEYCODE_ARRAY[0]));
+static USHORT KEYCODE_ARRAY_SIZE = SAL_N_ELEMENTS(KEYCODE_ARRAY);
 
 //-----------------------------------------------
 // seems to be needed to layout the list box, which shows all
@@ -1697,3 +1713,5 @@ SvxShortcutAssignDlg::~SvxShortcutAssignDlg()
 
 
 // .uno:InsertSymbol?Symbols:string=bla
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
