@@ -1,7 +1,8 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -77,6 +78,7 @@
 #include <dialmgr.hxx>
 #include <svtools/helpopt.hxx>
 #include <unotools/saveopt.hxx>
+#include <sal/macros.h>
 
 #include <com/sun/star/container/XContentEnumerationAccess.hpp>
 #include <com/sun/star/container/XNameAccess.hpp>
@@ -210,14 +212,20 @@ OfaMiscTabPage::OfaMiscTabPage(Window* pParent, const SfxItemSet& rSet ) :
     aPrintDlgCB			( this, CUI_RES( CB_PRINTDLG ) ),
     aDocStatusFL		( this, CUI_RES( FL_DOCSTATUS ) ),
     aDocStatusCB		( this, CUI_RES( CB_DOCSTATUS ) ),
+    aSaveAlwaysCB       ( this, CUI_RES( CB_SAVE_ALWAYS ) ),
     aTwoFigureFL		( this, CUI_RES( FL_TWOFIGURE ) ),
     aInterpretFT		( this, CUI_RES( FT_INTERPRET ) ),
     aYearValueField		( this, CUI_RES( NF_YEARVALUE ) ),
-    aToYearFT			( this, CUI_RES( FT_TOYEAR ) )
-
+    aToYearFT			( this, CUI_RES( FT_TOYEAR ) ),
+    aExperimentalCB     ( this, CUI_RES( CB_EXPERIMENTAL ) )
 {
     FreeResource();
 
+#if not ENABLE_HELP_FORMATTING
+    aHelpFormatFT.Hide();
+    aHelpFormatLB.Hide();
+#endif
+
     if (!lcl_HasSystemFilePicker())
     {
         aFileDlgFL.Hide();
@@ -232,19 +240,22 @@ OfaMiscTabPage::OfaMiscTabPage(Window* pParent, const SfxItemSet& rSet ) :
 #ifdef WNT
     aFileDlgCB.SetToggleHdl( LINK( this, OfaMiscTabPage, OnFileDlgToggled ) );
 #else
+    aODMADlgCB.Hide();
+#endif
+
+    if (!aODMADlgCB.IsVisible())
     {
-        aODMADlgCB.Hide();
         // rearrange the following controls
-        Point aNewPos = aDocStatusFL.GetPosPixel();
+        Point aNewPos = aPrintDlgFL.GetPosPixel();
         long nDelta = aNewPos.Y() - aODMADlgCB.GetPosPixel().Y();
 
         Window* pWins[] =
         {
-            &aDocStatusFL, &aDocStatusCB, &aTwoFigureFL,
-            &aInterpretFT, &aYearValueField, &aToYearFT
+            &aPrintDlgFL, &aPrintDlgCB, &aDocStatusFL, &aDocStatusCB, &aSaveAlwaysCB,
+            &aTwoFigureFL, &aInterpretFT, &aYearValueField, &aToYearFT, &aExperimentalCB
         };
         Window** pCurrent = pWins;
-        const sal_Int32 nCount = sizeof( pWins ) / sizeof( pWins[ 0 ] );
+        const sal_Int32 nCount = SAL_N_ELEMENTS( pWins );
         for ( sal_Int32 i = 0; i < nCount; ++i, ++pCurrent )
         {
             aNewPos = (*pCurrent)->GetPosPixel();
@@ -252,21 +263,20 @@ OfaMiscTabPage::OfaMiscTabPage(Window* pParent, const SfxItemSet& rSet ) :
             (*pCurrent)->SetPosPixel( aNewPos );
         }
     }
-#endif
 
     if ( !aFileDlgCB.IsVisible() )
     {
         // rearrange the following controls
-        Point aNewPos = aDocStatusFL.GetPosPixel();
+        Point aNewPos = aPrintDlgFL.GetPosPixel();
         long nDelta = aNewPos.Y() - aFileDlgFL.GetPosPixel().Y();
 
         Window* pWins[] =
         {
-            &aPrintDlgFL, &aPrintDlgCB, &aDocStatusFL, &aDocStatusCB, &aTwoFigureFL,
-            &aInterpretFT, &aYearValueField, &aToYearFT
+            &aPrintDlgFL, &aPrintDlgCB, &aDocStatusFL, &aDocStatusCB, &aSaveAlwaysCB,
+            &aTwoFigureFL, &aInterpretFT, &aYearValueField, &aToYearFT, &aExperimentalCB
         };
         Window** pCurrent = pWins;
-        const sal_Int32 nCount = sizeof( pWins ) / sizeof( pWins[ 0 ] );
+        const sal_Int32 nCount = SAL_N_ELEMENTS( pWins );
         for ( sal_Int32 i = 0; i < nCount; ++i, ++pCurrent )
         {
             aNewPos = (*pCurrent)->GetPosPixel();
@@ -280,23 +290,23 @@ OfaMiscTabPage::OfaMiscTabPage(Window* pParent, const SfxItemSet& rSet ) :
         aFileDlgCB.Disable();
     }
 
-    if ( aPrintDlgCB.IsVisible() )
+    if ( !aPrintDlgCB.IsVisible() )
     {
         // rearrange the following controls
         Point aNewPos = aDocStatusFL.GetPosPixel();
-        long nDelta = aNewPos.Y() - aFileDlgFL.GetPosPixel().Y();
+        long nDelta = aNewPos.Y() - aPrintDlgFL.GetPosPixel().Y();
 
         Window* pWins[] =
         {
-            &aDocStatusFL, &aDocStatusCB, &aTwoFigureFL,
-            &aInterpretFT, &aYearValueField, &aToYearFT
+            &aDocStatusFL, &aDocStatusCB, &aSaveAlwaysCB, &aTwoFigureFL,
+            &aInterpretFT, &aYearValueField, &aToYearFT, &aExperimentalCB
         };
         Window** pCurrent = pWins;
-        const sal_Int32 nCount = sizeof( pWins ) / sizeof( pWins[ 0 ] );
+        const sal_Int32 nCount = SAL_N_ELEMENTS( pWins );
         for ( sal_Int32 i = 0; i < nCount; ++i, ++pCurrent )
         {
             aNewPos = (*pCurrent)->GetPosPixel();
-            aNewPos.Y() += nDelta;
+            aNewPos.Y() -= nDelta;
             (*pCurrent)->SetPosPixel( aNewPos );
         }
     }
@@ -419,6 +429,20 @@ BOOL OfaMiscTabPage::FillItemSet( SfxItemSet& rSet )
         bModified = TRUE;
     }
 
+    if ( aSaveAlwaysCB.IsChecked() != aSaveAlwaysCB.GetSavedValue() )
+    {
+        SvtMiscOptions aMiscOpt;
+        aMiscOpt.SetSaveAlwaysAllowed( aSaveAlwaysCB.IsChecked() );
+        bModified = TRUE;
+    }
+
+    if ( aExperimentalCB.IsChecked() != aExperimentalCB.GetSavedValue() )
+    {
+        SvtMiscOptions aMiscOpt;
+        aMiscOpt.SetExperimentalMode( aExperimentalCB.IsChecked() );
+        bModified = TRUE;
+    }
+
     const SfxUInt16Item* pUInt16Item =
         PTR_CAST( SfxUInt16Item, GetOldItem( rSet, SID_ATTR_YEAR2000 ) );
     USHORT nNum = (USHORT)aYearValueField.GetText().ToInt32();
@@ -460,6 +484,10 @@ void OfaMiscTabPage::Reset( const SfxItemSet& rSet )
     aFileDlgCB.SaveValue();
     aPrintDlgCB.Check( !aMiscOpt.UseSystemPrintDialog() );
     aPrintDlgCB.SaveValue();
+    aSaveAlwaysCB.Check( aMiscOpt.IsSaveAlwaysAllowed() );
+    aSaveAlwaysCB.SaveValue();
+    aExperimentalCB.Check( aMiscOpt.IsExperimentalMode() );
+    aExperimentalCB.SaveValue();
 
     aODMADlgCB.Check( aMiscOpt.TryODMADialog() );
     aODMADlgCB.SaveValue();
@@ -792,7 +820,7 @@ OfaViewTabPage::OfaViewTabPage(Window* pParent, const SfxItemSet& rSet ) :
     DELETEZ( pFontAntiAliasing );
 
     Point aPos;
-    for ( sal_Int32 i = 0; i < sizeof( pMiscOptions ) / sizeof( pMiscOptions[0] ); ++i )
+    for ( sal_Int32 i = 0; i < SAL_N_ELEMENTS( pMiscOptions ); ++i )
     {
         aPos = pMiscOptions[i]->GetPosPixel( );
         aPos.Y() -= nMoveUp;
@@ -833,7 +861,7 @@ OfaViewTabPage::OfaViewTabPage(Window* pParent, const SfxItemSet& rSet ) :
                 aIconStyleLB.RemoveEntry( nItem );
                 aIconStyleItemId[n] = 0;
             }
-        }        
+        }
     }
 
     // add real theme name to 'auto' theme, e.g. 'auto' => 'auto (classic)'
@@ -843,10 +871,14 @@ OfaViewTabPage::OfaViewTabPage(Window* pParent, const SfxItemSet& rSet ) :
 
         aAutoStr += ::rtl::OUString::createFromAscii( " (" );
 
-        ULONG nAutoStyle = aStyleSettings.GetAutoSymbolsStyle();
+        // prefer the icon style set by the desktop native widgets modules
+        ULONG nAutoStyle = aStyleSettings.GetPreferredSymbolsStyle();
+        // fallback to the statically defined values
+        if ( nAutoStyle == STYLE_SYMBOLS_AUTO || !aIconStyleItemId[nAutoStyle] )
+            nAutoStyle = aStyleSettings.GetAutoSymbolsStyle();
         if ( aIconStyleItemId[nAutoStyle] )
             aAutoStr += aIconStyleLB.GetEntry( aIconStyleItemId[nAutoStyle] );
-  
+
         aIconStyleLB.RemoveEntry( 0 );
         aIconStyleLB.InsertEntry( aAutoStr += ::rtl::OUString::createFromAscii( ")" ), 0 );
         // separate auto and other icon themes
@@ -1500,9 +1532,18 @@ BOOL OfaLanguagesTabPage::FillItemSet( SfxItemSet& rSet )
     pLangConfig->aLanguageOptions.BlockBroadcasts( TRUE );
     pLangConfig->aLinguConfig.BlockBroadcasts( TRUE );
 
-    if(aCTLSupportCB.IsChecked() &&
-            (aCTLSupportCB.GetSavedValue() != aCTLSupportCB.IsChecked()) ||
-            (aComplexLanguageLB.GetSavedValue() != aComplexLanguageLB.GetSelectEntryPos()))
+    /*
+     * Sequence checking only matters when CTL support is enabled.
+     *
+     * So we only need to check for sequence checking if
+     * a) previously it was unchecked and is now checked or
+     * b) it was already checked but the CTL language has changed
+     */
+    if (
+         aCTLSupportCB.IsChecked() &&
+         (aCTLSupportCB.GetSavedValue() != STATE_CHECK ||
+         aComplexLanguageLB.GetSavedValue() != aComplexLanguageLB.GetSelectEntryPos())
+       )
     {
         //sequence checking has to be switched on depending on the selected CTL language
         LanguageType eCTLLang = aComplexLanguageLB.GetSelectLanguage();
@@ -1598,7 +1639,7 @@ BOOL OfaLanguagesTabPage::FillItemSet( SfxItemSet& rSet )
     if(aDecimalSeparatorCB.GetSavedValue() != aDecimalSeparatorCB.IsChecked())
         pLangConfig->aSysLocaleOptions.SetDecimalSeparatorAsLocale(aDecimalSeparatorCB.IsChecked());
 
-    // Configured currency, for example, USD-en-US or EUR-de-DE, or empty for locale default. 
+    // Configured currency, for example, USD-en-US or EUR-de-DE, or empty for locale default.
     OUString sOldCurr = pLangConfig->aSysLocaleOptions.GetCurrencyConfigString();
     USHORT nCurrPos = aCurrencyLB.GetSelectEntryPos();
     const NfCurrencyEntry* pCurr = (const NfCurrencyEntry*)
@@ -1967,3 +2008,4 @@ IMPL_LINK( OfaLanguagesTabPage, LocaleSettingHdl, SvxLanguageBox*, pBox )
     return 0;
 }
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
