@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -71,7 +72,6 @@ struct GeneralTabPage_Impl
 // -----------------------------------------------------------------------
 
 // kommt aus adritem.cxx
-//CHINA001 extern String ConvertToStore_Impl( const String& );
 //copy from adritem.cxx, since it will leave in svx.
 String ConvertToStore_Impl( const String& rText )
 {
@@ -186,6 +186,7 @@ SvxGeneralTabPage::SvxGeneralTabPage( Window* pParent, const SfxItemSet& rCoreSe
     }
     else if ( LANGUAGE_JAPANESE == eLang ||
           LANGUAGE_KOREAN == eLang ||
+          LANGUAGE_HUNGARIAN == eLang ||
           LANGUAGE_CHINESE_TRADITIONAL == eLang ||
           LANGUAGE_CHINESE_SIMPLIFIED == eLang)
     {
@@ -579,3 +580,4 @@ int SvxGeneralTabPage::DeactivatePage( SfxItemSet* _pSet )
     return LEAVE_PAGE;
 }
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
