@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -51,9 +52,9 @@
 #include <dialmgr.hxx>
 #include "svx/htmlmode.hxx"
 #include <vcl/msgbox.hxx>
-#include "svx/flagsdef.hxx"	//CHINA001
+#include "svx/flagsdef.hxx"
 #include <sfx2/request.hxx>
-#include <svl/intitem.hxx> //CHINA001
+#include <svl/intitem.hxx>
 #include <sfx2/itemconnect.hxx>
 #include "borderconn.hxx"
 
@@ -396,7 +397,7 @@ SvxBorderTabPage::SvxBorderTabPage( Window* pParent,
         AddItemConnection( svx::CreateFrameLineConnection( SID_ATTR_BORDER_DIAG_TLBR, aFrameSel, svx::FRAMEBORDER_TLBR ) );
     if( aFrameSel.IsBorderEnabled( svx::FRAMEBORDER_BLTR ) )
         AddItemConnection( svx::CreateFrameLineConnection( SID_ATTR_BORDER_DIAG_BLTR, aFrameSel, svx::FRAMEBORDER_BLTR ) );
-    // --> OD 2005-03-01 #i43593# - item connection doesn't work for Writer,
+    // #i43593# - item connection doesn't work for Writer,
     // because the Writer item sets contain these items
     // checkbox "Merge with next paragraph" only visible for Writer dialog format.paragraph
     AddItemConnection( new sfx::CheckBoxConnection( SID_ATTR_BORDER_CONNECT, aMergeWithNextCB, sfx::ITEMCONN_DEFAULT ) );
@@ -404,7 +405,6 @@ SvxBorderTabPage::SvxBorderTabPage( Window* pParent,
     // checkbox "Merge adjacent line styles" only visible for Writer dialog format.table
     AddItemConnection( new sfx::CheckBoxConnection( SID_SW_COLLAPSING_BORDERS, aMergeAdjacentBordersCB, sfx::ITEMCONN_DEFAULT ) );
     aMergeAdjacentBordersCB.Hide();
-    // <--
 }
 
 // -----------------------------------------------------------------------
@@ -565,9 +565,10 @@ void SvxBorderTabPage::Reset( const SfxItemSet& rSet )
     {
         // Do all visible lines show the same line widths?
         USHORT nPrim, nDist, nSecn;
-        bool bWidthEq = aFrameSel.GetVisibleWidth( nPrim, nDist, nSecn );
+        SvxBorderStyle nStyle;
+        bool bWidthEq = aFrameSel.GetVisibleWidth( nPrim, nDist, nSecn, nStyle );
         if( bWidthEq )
-            aLbLineStyle.SelectEntry( nPrim * 100, nSecn * 100, nDist * 100 );
+            aLbLineStyle.SelectEntry( nPrim * 100, nSecn * 100, nDist * 100, nStyle );
         else
             aLbLineStyle.SelectEntryPos( 1 );
 
@@ -932,13 +933,31 @@ IMPL_LINK( SvxBorderTabPage, SelColHdl_Impl, ListBox *, pLb )
 
 // -----------------------------------------------------------------------
 
+SvxBorderStyle lcl_getBorderStyle( USHORT nStyle )
+{
+    SvxBorderStyle nResult = SOLID;
+    switch ( nStyle )
+    {
+        case STYLE_DOTTED:
+            nResult = DOTTED;
+            break;
+        case STYLE_DASHED:
+            nResult = DASHED;
+            break;
+        default:
+            nResult = SOLID;
+    }
+    return nResult;
+}
+
 IMPL_LINK( SvxBorderTabPage, SelStyleHdl_Impl, ListBox *, pLb )
 {
     if ( pLb == &aLbLineStyle )
         aFrameSel.SetStyleToSelection(
             static_cast< USHORT >( aLbLineStyle.GetSelectEntryLine1() / 100 ),
             static_cast< USHORT >( aLbLineStyle.GetSelectEntryDistance() / 100 ),
-            static_cast< USHORT >( aLbLineStyle.GetSelectEntryLine2() / 100 ) );
+            static_cast< USHORT >( aLbLineStyle.GetSelectEntryLine2() / 100 ),
+            lcl_getBorderStyle( aLbLineStyle.GetSelectEntryStyle() ) );
 
     return 0;
 }
@@ -1102,6 +1121,8 @@ void SvxBorderTabPage::FillLineListBox_Impl()
 
     aLbLineStyle.InsertEntry( LINE_WIDTH0 );
     aLbLineStyle.InsertEntry( LINE_WIDTH5 );
+    aLbLineStyle.InsertEntry( LINE_WIDTH5, 0, 0, STYLE_DOTTED );
+    aLbLineStyle.InsertEntry( LINE_WIDTH5, 0, 0, STYLE_DASHED );
     aLbLineStyle.InsertEntry( LINE_WIDTH1 );
     aLbLineStyle.InsertEntry( LINE_WIDTH2 );
     aLbLineStyle.InsertEntry( LINE_WIDTH3 );
@@ -1225,9 +1246,6 @@ IMPL_LINK( SvxBorderTabPage, SyncHdl_Impl, CheckBox*, pBox)
     return 0;
 }
 
-/* -----------------------------03.06.2002 10:15------------------------------
-
- ---------------------------------------------------------------------------*/
 void SvxBorderTabPage::DataChanged( const DataChangedEvent& rDCEvt )
 {
     if( (rDCEvt.GetType() == DATACHANGED_SETTINGS) && (rDCEvt.GetFlags() & SETTINGS_STYLE) )
@@ -1236,14 +1254,14 @@ void SvxBorderTabPage::DataChanged( const DataChangedEvent& rDCEvt )
     SfxTabPage::DataChanged( rDCEvt );
 }
 
-void SvxBorderTabPage::PageCreated (SfxAllItemSet aSet) //add CHINA001
+void SvxBorderTabPage::PageCreated (SfxAllItemSet aSet)
 {
     SFX_ITEMSET_ARG (&aSet,pSWModeItem,SfxUInt16Item,SID_SWMODE_TYPE,sal_False);
     SFX_ITEMSET_ARG (&aSet,pFlagItem,SfxUInt32Item,SID_FLAG_TYPE,sal_False);
     if (pSWModeItem)
     {
         nSWMode = pSWModeItem->GetValue();
-        // --> OD 2005-03-01 #i43593#
+        // #i43593#
         // show checkbox <aMergeWithNextCB> for format.paragraph
         if ( nSWMode == SW_BORDER_MODE_PARA )
         {
@@ -1265,3 +1283,4 @@ void SvxBorderTabPage::PageCreated (SfxAllItemSet aSet) //add CHINA001
 
 // ============================================================================
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
