@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -36,9 +37,7 @@
 #include <svl/itemprop.hxx>
 #include <uno/environment.h>
 #include <svl/urihelper.hxx>
-#ifndef _TOOLKIT_UNOHLP_HXX
 #include <toolkit/helper/vclunohelper.hxx>
-#endif
 #include <comphelper/processfactory.hxx>
 #include <cppuhelper/factory.hxx>	// helper for factories
 #include <com/sun/star/sdbc/ResultSetType.hpp>
@@ -65,9 +64,7 @@
 #include <svtools/svmedit.hxx>
 
 #include "bibresid.hxx"
-#ifndef BIB_HRC
 #include "bib.hrc"
-#endif
 #include "bibcont.hxx"
 #include "bibbeam.hxx"
 #include "bibmod.hxx"
@@ -290,7 +287,7 @@ void BibliographyLoader::load(const Reference< XFrame > & rFrame, const rtl::OUS
 {
     //!
 
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     m_pBibMod = OpenBibModul();
 
     String aURLStr( rURL );
@@ -313,7 +310,7 @@ void BibliographyLoader::loadView(const Reference< XFrame > & rFrame, const rtl:
         const Sequence< PropertyValue >& /*rArgs*/,
         const Reference< XLoadEventListener > & rListener)
 {
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     //!
     if(!m_pBibMod)
         m_pBibMod = OpenBibModul();
@@ -805,3 +802,4 @@ void BibliographyLoader::removeVetoableChangeListener(
 
 
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
