@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -62,9 +63,7 @@
 #include <svtools/svtabbx.hxx>
 #include <svtools/headbar.hxx>
 #include <vcl/dialog.hxx>
-#ifndef _SV_BUTTON_HXX
 #include <vcl/button.hxx>
-#endif
 #include <vcl/lstbox.hxx>
 #include <vcl/fixed.hxx>
 #include <vcl/group.hxx>
@@ -1832,3 +1831,5 @@ sal_Bool BibDataManager::HasActiveConnection()
 {
     return getConnection( m_xForm ).is();
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
