@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -36,9 +37,7 @@
 #include <com/sun/star/frame/FrameSearchFlag.hpp>
 #include <datman.hxx>
 #include <tools/debug.hxx>
-#ifndef _SVX_SVXIDS_HRC
 #include <svx/svxids.hrc>
-#endif
 #include <svtools/miscopt.hxx>
 #include <svtools/imgdef.hxx>
 #include <vcl/svapp.hxx>
@@ -47,10 +46,8 @@
 #include "toolbar.hrc"
 #include "bibresid.hxx"
 
-#ifndef BIBTOOLS_HXX
 #include "bibtools.hxx"
-#endif
-#include <vos/mutex.hxx>
+#include <osl/mutex.hxx>
 
 using namespace ::rtl;
 using namespace ::com::sun::star;
@@ -77,7 +74,7 @@ void BibToolBarListener::statusChanged(const ::com::sun::star::frame::FeatureSta
 {
     if(rEvt.FeatureURL.Complete == aCommand)
     {
-        vos::OGuard aGuard(Application::GetSolarMutex());
+        SolarMutexGuard aGuard;
         pToolBar->EnableItem(nIndex,rEvt.IsEnabled);
 
         ::com::sun::star::uno::Any aState=rEvt.State;
@@ -112,7 +109,7 @@ void BibTBListBoxListener::statusChanged(const ::com::sun::star::frame::FeatureS
 {
     if(rEvt.FeatureURL.Complete == GetCommand())
     {
-        vos::OGuard aGuard(Application::GetSolarMutex());
+        SolarMutexGuard aGuard;
         pToolBar->EnableSourceList(rEvt.IsEnabled);
 
         Any aState = rEvt.State;
@@ -152,7 +149,7 @@ void BibTBQueryMenuListener::statusChanged(const frame::FeatureStateEvent& rEvt)
 {
     if(rEvt.FeatureURL.Complete == GetCommand())
     {
-        vos::OGuard aGuard(Application::GetSolarMutex());
+        SolarMutexGuard aGuard;
         pToolBar->EnableSourceList(rEvt.IsEnabled);
 
         uno::Any aState=rEvt.State;
@@ -190,7 +187,7 @@ void BibTBEditListener::statusChanged(const frame::FeatureStateEvent& rEvt)throw
 {
     if(rEvt.FeatureURL.Complete == GetCommand())
     {
-        vos::OGuard aGuard(Application::GetSolarMutex());
+        SolarMutexGuard aGuard;
         pToolBar->EnableQuery(rEvt.IsEnabled);
 
         uno::Any aState=rEvt.State;
@@ -645,3 +642,5 @@ void BibToolBar::AdjustToolBox()
         Invalidate();
     }
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
