@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -28,6 +29,12 @@
 // MARKER(update_precomp.py): autogen include statement, do not remove
 #include "precompiled_extensions.hxx"
 
+#ifdef AIX
+#define _LINUX_SOURCE_COMPAT
+#include <sys/timer.h>
+#undef _LINUX_SOURCE_COMPAT
+#endif
+
 #if STLPORT_VERSION>=321
 #include <cstdarg>
 #endif
@@ -46,7 +53,7 @@ PluginConnector::PluginConnector( int nSocket ) :
 
 PluginConnector::~PluginConnector()
 {
-    NAMESPACE_VOS(OGuard) aGuard( m_aUserEventMutex );
+    osl::MutexGuard aGuard( m_aUserEventMutex );
     for( std::vector< PluginConnector* >::iterator it = allConnectors.begin();
          it != allConnectors.end(); ++it )
     {
@@ -60,7 +67,7 @@ PluginConnector::~PluginConnector()
 
 IMPL_LINK( PluginConnector, NewMessageHdl, Mediator*, /*pMediator*/ )
 {
-    NAMESPACE_VOS(OGuard) aGuard( m_aUserEventMutex );
+    osl::MutexGuard aGuard( m_aUserEventMutex );
     bool bFound = false;
     for( std::vector< PluginConnector* >::iterator it = allConnectors.begin();
          it != allConnectors.end() && bFound == false; ++it )
@@ -87,7 +94,7 @@ IMPL_LINK( PluginConnector, WorkOnNewMessageHdl, Mediator*, /*pMediator*/ )
         return 0;
 /*
     {
-        NAMESPACE_VOS(OGuard) aGuard( m_aUserEventMutex );
+        osl::MutexGuard aGuard( m_aUserEventMutex );
         m_aUserEventIDs.pop_front();
     }
 */
@@ -619,3 +626,5 @@ NPError UnxPluginComm::NPP_SetValue( NPP /*instance*/, NPNVariable /*variable*/,
 {
     return 0;
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
