@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -34,11 +35,9 @@
 
 #include <rtl/wstring.hxx>
 #include <osl/time.h>
-//#include <vos/dynload.hxx>
-//#include <vos/diagnose.hxx>
 #include <usr/weak.hxx>
 #include <tools/string.hxx>
-#include <vos/conditn.hxx>
+#include <osl/conditn.hxx>
 
 #include <smart/com/sun/star/io/XOutputStream.hxx>
 #include <smart/com/sun/star/xml/sax/SAXParseException.hxx>
@@ -53,7 +52,6 @@
 #include "factory.hxx"
 
 using namespace rtl;
-using namespace vos;
 using namespace usr;
 
 
@@ -909,3 +907,4 @@ UNO_INTERFACE(XInterface) EXTERN_SERVICE_CALLTYPE exService_getFactory
 }
 
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
