@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -32,7 +33,6 @@
 #include <com/sun/star/uno/Reference.h>
 #include <com/sun/star/linguistic2/XSearchableDictionaryList.hpp>
 
-//#include <com/sun/star/linguistic2/SpellFailure.hpp>
 #include <cppuhelper/factory.hxx>	// helper for factories
 #include <com/sun/star/registry/XRegistryKey.hpp>
 #include <i18npool/mslangid.hxx>
@@ -44,9 +44,7 @@
 
 #include <hyphen.h>
 
-#ifndef _HYPHENIMP_HXX
 #include <hyphenimp.hxx>
-#endif
 
 #include <linguistic/hyphdta.hxx>
 #include <rtl/ustring.hxx>
@@ -980,3 +978,5 @@ void * SAL_CALL Hyphenator_getFactory( const sal_Char * pImplName,
 #undef CAPTYPE_INITCAP
 #undef CAPTYPE_ALLCAP
 #undef CAPTYPE_MIXED
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
